@@ -2,7 +2,6 @@
 
 use deno_core::include_js_files;
 use deno_core::Extension;
-use std::path::PathBuf;
 
 pub fn init() -> Extension {
   Extension::builder()
@@ -13,7 +12,3 @@ pub fn init() -> Extension {
     ))
     .build()
 }
-
-pub fn get_declaration() -> PathBuf {
-  PathBuf::from(env!("CARGO_MANIFEST_DIR")).join("lib.deno_console.d.ts")
-}
